@@ -3,7 +3,7 @@ package Dist::Zilla::Plugin::Test::MixedScripts;
 use v5.16;
 use warnings;
 
-# ABSTRACT: author tests to ensure there is no mixed unicode
+# ABSTRACT: author tests to ensure there is no mixed Unicode
 
 use Moose;
 
@@ -26,7 +26,7 @@ with
   },
   'Dist::Zilla::Role::PrereqSource';
 
-our $VERSION = 'v0.1.3';
+our $VERSION = 'v0.1.4';
 
 
 has filename => (
@@ -136,7 +136,7 @@ sub register_prereqs {
             phase => 'develop',
             type  => 'requires',
         },
-        'Test::More'         => '1.302200',
+        'Test2::Tools::Basic' => '1.302200',
         'Test::MixedScripts' => 'v0.3.0',
     );
 }
@@ -149,11 +149,13 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Test::MixedScripts - author tests to ensure there is no mixed unicode
+Dist::Zilla::Plugin::Test::MixedScripts - author tests to ensure there is no mixed Unicode
 
 =head1 VERSION
 
-version v0.1.3
+version v0.1.4
+
+=for stopwords Cushing Etheridge Florian Ragwitz Unicode
 
 =head1 DESCRIPTION
 
@@ -162,7 +164,7 @@ This generates an author L<Test::MixedScripts>.
 This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the file F<xt/author/mixed-unicode-scripts.t> for
 testing against mixed Unicode scripts that are potentially confusing or malicious.
 
-For example, the text for the domain names "E<0x043e>nE<0x0435>.example.com" and "one.example.com" look indistinguishable in many fonts,
+For example, the text for the domain names C<< E<0x043e>nE<0x0435>.example.com >> and C<one.example.com> look indistinguishable in many fonts,
 but the first one has Cyrillic letters.  If your software interacted with a service on the second domain, then someone
 can operate a service on the first domain and attempt to fool developers into using their domain instead.
 
@@ -251,6 +253,12 @@ Robert Rothenberg <rrwo@cpan.org>
 This code was based on L<Dist::Zilla::Plugin::Test::EOL> by Florian Ragwitz <rafl@debian.org>, Caleb Cushing
 <xenoterracide@gmail.com> and Karen Etheridge <ether@cpan.org>.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Graham Knop
+
+Graham Knop <haarg@haarg.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2025 by Robert Rothenberg.
@@ -267,7 +275,7 @@ use warnings;
 
 # This test was generated with {{ ref $plugin }} {{ $plugin->VERSION }}.
 
-use Test::More 1.302200;
+use Test2::Tools::Basic 1.302200;
 
 use Test::MixedScripts qw( file_scripts_ok );
 
